pygeodesy.angles

Package pygeodesy :: Module angles |
[frames] | no frames]

# Module angles

Classes Ang, Deg, Rad and Lambertian accurately representing an angle as a 3-tuple `(sine, cosine, turns)`, with `turns` the number of full turns.

Transcoded to pure Python from Karney's GeographicLib 2.7 C++ class AngleT.

Copyright (C) Charles Karney (2024-2025) and licensed under the MIT/X11 License. For more information, see the GeographicLib 2.7 documentation.

Version: 25.12.02

Classes
| Ang An accurate representation of angles, as 3-tuple `(s, c, n)`.
| Lambertian A `Lambertian` in `radians`.

Functions
Deg(deg, **name) Return an Ang from `deg` degrees or an other Ang. |
isAng(ang) Is `ang` an Ang instance? |
Rad(rad, **name) Return an Ang from `rad` radians or an other Ang. |

Variables
| __all__ = `_ALL_LAZY.angles`